@@ -57,7 +57,7 @@ using Tellico::Data::Document;
 Document* Document::s_self = nullptr;
 
 Document::Document() : QObject(), m_coll(nullptr), m_isModified(false),
-    m_loadAllImages(false), m_validFile(false), m_importer(nullptr), m_cancelImageWriting(false),
+    m_loadAllImages(false), m_validFile(false), m_importer(nullptr), m_cancelImageWriting(true),
     m_fileFormat(Import::TellicoImporter::Unknown) {
   m_allImagesOnDisk = Config::imageLocation() != Config::ImagesInFile;
   newDocument(Collection::Book);
@@ -92,7 +92,7 @@ void Document::slotSetModified(bool modified_/*=true*/) {
  * the document modified flag
  */
 void Document::slotSetClean(bool clean_) {
-   slotSetModified(!clean_);
+  slotSetModified(!clean_);
 }
 
 bool Document::newDocument(int type_) {
@@ -131,12 +131,11 @@ bool Document::openDocument(const QUrl& url_) {
   m_importer = new Import::TellicoImporter(url_, m_loadAllImages);
 
   ProgressItem& item = ProgressManager::self()->newProgressItem(m_importer, m_importer->progressLabel(), true);
-  connect(m_importer, SIGNAL(signalTotalSteps(QObject*, qulonglong)),
-          ProgressManager::self(), SLOT(setTotalSteps(QObject*, qulonglong)));
-  connect(m_importer, SIGNAL(signalProgress(QObject*, qulonglong)),
-          ProgressManager::self(), SLOT(setProgress(QObject*, qulonglong)));
-  connect(&item, &Tellico::ProgressItem::signalCancelled,
-          m_importer.data(), &Tellico::Import::TellicoImporter::slotCancel);
+  connect(m_importer, &Import::Importer::signalTotalSteps,
+          ProgressManager::self(), &ProgressManager::setTotalSteps);
+  connect(m_importer, &Import::Importer::signalProgress,
+          ProgressManager::self(), &ProgressManager::setProgress);
+  connect(&item, &ProgressItem::signalCancelled, m_importer, &Import::Importer::slotCancel);
   ProgressItem::Done done(m_importer);
 
   CollPtr coll = m_importer->collection();
@@ -333,9 +332,8 @@ Tellico::Data::MergePair Document::mergeCollection(Tellico::Data::CollPtr coll1_
     Data::EntryPtr matchEntry, currEntry;
     // first, if we're checking against same ID
     if(checkSameId) {
-      currEntry = currEntries.first()->collection()->entryById(newEntry->id());
-      if(currEntry &&
-         currEntry->collection()->sameEntry(currEntry, newEntry) >= EntryComparison::ENTRY_PERFECT_MATCH) {
+      currEntry = coll1_->entryById(newEntry->id());
+      if(currEntry && coll1_->sameEntry(currEntry, newEntry) >= EntryComparison::ENTRY_PERFECT_MATCH) {
         // only have to compare against perfect match
         matchEntry = currEntry;
       }
@@ -343,9 +341,9 @@ Tellico::Data::MergePair Document::mergeCollection(Tellico::Data::CollPtr coll1_
     if(!matchEntry) {
       // alternative is to loop over them all
       for(int i = 0; i < currTotal; ++i) {
-        // since we're sorted by title, track the index of the previous match and starts comparison there
+        // since we're sorted by title, track the index of the previous match and start comparison there
         currEntry = currEntries.at((i+lastMatchId) % currTotal);
-        int match = currEntry->collection()->sameEntry(currEntry, newEntry);
+        const int match = coll1_->sameEntry(currEntry, newEntry);
         if(match >= EntryComparison::ENTRY_PERFECT_MATCH) {
           matchEntry = currEntry;
           lastMatchId = (i+lastMatchId) % currTotal;
@@ -795,7 +793,7 @@ bool Document::mergeEntry(Data::EntryPtr e1, Data::EntryPtr e2, MergeConflictRes
       ret = true;
 #endif
     } else if(resolver_) {
-      int resolverResponse = resolver_->resolve(e1, e2, field);
+      const int resolverResponse = resolver_->resolve(e1, e2, field);
       if(resolverResponse == MergeConflictResolver::CancelMerge) {
         ret = false; // we got cancelled
         return false; // cancel all the merge right now
@@ -803,7 +801,7 @@ bool Document::mergeEntry(Data::EntryPtr e1, Data::EntryPtr e2, MergeConflictRes
         e1->setField(field, e2->field(field));
       }
     } else {
-      myDebug() << "Doing nothing for" << field->name();
+//      myDebug() << "Keeping value of" << field->name() << "for" << e1->field(QStringLiteral("title"));
     }
   }
   return ret;
