@@ -71,7 +71,13 @@ public:
     CA = 5,
     CN = 6,
     ES = 7,
-    IT = 8
+    IT = 8,
+    BR = 9,
+    AU = 10,
+    IN = 11,
+    MX = 12,
+    TR = 13,
+    XX = 14
   };
 
   enum ImageSize {
@@ -98,6 +104,8 @@ public:
   struct SiteData {
     QString title;
     QUrl url;
+    QString country;
+    QString countryName;
   };
   static const SiteData& siteData(int site);
 
