@@ -100,7 +100,9 @@ enum Type {
   VideoGameGeek,
   DBC,
   IGDB,
-  Kino
+  Kino,
+  MobyGames,
+  ComicVine
 };
 
   }
