@@ -68,6 +68,8 @@
 #include "dbcfetcher.h"
 #include "igdbfetcher.h"
 #include "kinofetcher.h"
+#include "mobygamesfetcher.h"
+#include "comicvinefetcher.h"
 
 /**
  * Ideally, I'd like these initializations to be in each cpp file for each collection type
@@ -121,6 +123,8 @@ Tellico::Fetch::FetcherInitializer::FetcherInitializer() {
   RegisterFetcher<Fetch::DBCFetcher> registerDBC(DBC);
   RegisterFetcher<Fetch::IGDBFetcher> registerIGDB(IGDB);
   RegisterFetcher<Fetch::KinoFetcher> registerKino(Kino);
+  RegisterFetcher<Fetch::MobyGamesFetcher> registerMobyGames(MobyGames);
+  RegisterFetcher<Fetch::ComicVineFetcher> registerComicVine(ComicVine);
 
   Fetch::Manager::self()->loadFetchers();
 }
