@@ -134,7 +134,7 @@ void KinoFetcher::slotComplete(KJob*) {
   QString s = Tellico::decodeHTML(data);
 #if 0
   myWarning() << "Remove debug from kinofetcher.cpp";
-  QFile f(QLatin1String("/tmp/test.html"));
+  QFile f(QStringLiteral("/tmp/test.html"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
     t.setCodec("UTF-8");
@@ -205,7 +205,7 @@ Tellico::Data::EntryPtr KinoFetcher::fetchEntryHook(uint uid_) {
 
 #if 0
   myWarning() << "Remove debug from kinofetcher.cpp";
-  QFile f(QLatin1String("/tmp/test2.html"));
+  QFile f(QStringLiteral("/tmp/test2.html"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
     t.setCodec("UTF-8");
@@ -227,7 +227,7 @@ void KinoFetcher::parseEntry(Data::EntryPtr entry, const QString& str_) {
   while(i.hasNext()) {
     QJsonDocument doc = QJsonDocument::fromJson(i.next().captured(1).toUtf8());
     QVariantMap objectMap = doc.object().toVariantMap();
-    if(mapValue(objectMap, "@type") != QLatin1String("Movie")) {
+    if(mapValue(objectMap, "@type") != QStringLiteral("Movie")) {
       continue;
     }
     entry->setField(QStringLiteral("director"), mapValue(objectMap, "director", "name"));
@@ -278,7 +278,7 @@ void KinoFetcher::parseEntry(Data::EntryPtr entry, const QString& str_) {
     QStringList allowed = entry->collection()->hasField(QStringLiteral("certification")) ?
                           entry->collection()->fieldByName(QStringLiteral("certification"))->allowed() :
                           QStringList();
-    if(!allowed.contains(QLatin1String("FSK 0 (DE)"))) {
+    if(!allowed.contains(QStringLiteral("FSK 0 (DE)"))) {
       allowed << QStringLiteral("FSK 0 (DE)")
               << QStringLiteral("FSK 6 (DE)")
               << QStringLiteral("FSK 12 (DE)")
@@ -287,15 +287,15 @@ void KinoFetcher::parseEntry(Data::EntryPtr entry, const QString& str_) {
       entry->collection()->fieldByName(QStringLiteral("certification"))->setAllowed(allowed);
     }
     QString c = certMatch.captured(1).remove(tagRx);
-    if(c == QLatin1String("ab 0")) {
+    if(c == QStringLiteral("ab 0")) {
       c = QStringLiteral("FSK 0 (DE)");
-    } else if(c == QLatin1String("ab 6")) {
+    } else if(c == QStringLiteral("ab 6")) {
       c = QStringLiteral("FSK 6 (DE)");
-    } else if(c == QLatin1String("ab 12")) {
+    } else if(c == QStringLiteral("ab 12")) {
       c = QStringLiteral("FSK 12 (DE)");
-    } else if(c == QLatin1String("ab 16")) {
+    } else if(c == QStringLiteral("ab 16")) {
       c = QStringLiteral("FSK 16 (DE)");
-    } else if(c == QLatin1String("ab 18")) {
+    } else if(c == QStringLiteral("ab 18")) {
       c = QStringLiteral("FSK 18 (DE)");
     }
     entry->setField(QStringLiteral("certification"), c);
