@@ -84,7 +84,7 @@ void KinoPoiskFetcher::search() {
   switch(request().key) {
     case Title:
       // first means return first result only
-      //q.addQueryItem(QLatin1String("first"), QLatin1String("yes"));
+      //q.addQueryItem(QStringLiteral("first"), QStringLiteral("yes"));
       q.addQueryItem(QStringLiteral("kp_query"), request().value);
       break;
 
@@ -131,7 +131,7 @@ void KinoPoiskFetcher::slotComplete(KJob*) {
   const QString output = Tellico::decodeHTML(data);
 #if 0
   myWarning() << "Remove debug from kinopoiskfetcher.cpp";
-  QFile f(QLatin1String("/tmp/test1.html"));
+  QFile f(QStringLiteral("/tmp/test1.html"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
     t.setCodec("UTF-8");
@@ -141,9 +141,9 @@ void KinoPoiskFetcher::slotComplete(KJob*) {
 #endif
 
   // look for a paragraph, class=",", with an internal /ink to "/level/1/film..."
-  QRegExp resultRx(QLatin1String("<p class=\"name\">\\s*"
-                                 "<a href=\"/level/1/film[^\"]+\".* data-url=\"([^\"]*)\".*>(.*)</a>\\s*"
-                                 "<span class=\"year\">(.*)</span"));
+  QRegExp resultRx(QStringLiteral("<p class=\"name\">\\s*"
+                                  "<a href=\"/level/1/film[^\"]+\".* data-url=\"([^\"]*)\".*>(.*)</a>\\s*"
+                                  "<span class=\"year\">(.*)</span"));
   resultRx.setMinimal(true);
 
   QString href, title, year;
@@ -186,10 +186,10 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::fetchEntryHook(uint uid_) {
     return Data::EntryPtr();
   }
 
-//  myDebug() << url.url();
 #if 0
+  myDebug() << url.url();
   myWarning() << "Remove debug from kinopoiskfetcher.cpp";
-  QFile f(QLatin1String("/tmp/test2.html"));
+  QFile f(QStringLiteral("/tmp/test2.html"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
     t.setCodec("UTF-8");
@@ -204,7 +204,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::fetchEntryHook(uint uid_) {
     return Data::EntryPtr();
   }
 
-  if(optionalFields().contains(QLatin1String("kinopoisk"))) {
+  if(optionalFields().contains(QStringLiteral("kinopoisk"))) {
     Data::FieldPtr field(new Data::Field(QStringLiteral("kinopoisk"), i18n("KinoPoisk Link"), Data::Field::URL));
     field->setCategory(i18n("General"));
     entry->collection()->addField(field);
@@ -220,34 +220,38 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
   Data::EntryPtr entry(new Data::Entry(coll));
   coll->addEntries(entry);
 
-  QRegExp tagRx(QLatin1String("<.*>"));
+  QRegExp tagRx(QStringLiteral("<.*>"));
   tagRx.setMinimal(true);
 
-  QRegExp anchorRx(QLatin1String("<a\\s+href=\".*\"[^>]*>(.*)</"));
+  QRegExp anchorRx(QStringLiteral("<a\\s+href=\".*\"[^>]*>(.*)</"));
   anchorRx.setMinimal(true);
 
-  QRegExp titleRx(QLatin1String("class=\"moviename-big\"[^>]*>([^<]+)</"));
+  QRegExp titleRx(QStringLiteral("class=\"moviename-big\"[^>]*>([^(]+).*</"));
+  titleRx.setMinimal(true);
   if(str_.contains(titleRx)) {
-    entry->setField(QStringLiteral("title"), titleRx.cap(1));
+    QString t = titleRx.cap(1);
+    t.remove(tagRx);
+    t = t.simplified();
+    entry->setField(QStringLiteral("title"), t);
   }
 
-  if(optionalFields().contains(QLatin1String("origtitle"))) {
+  if(optionalFields().contains(QStringLiteral("origtitle"))) {
     Data::FieldPtr f(new Data::Field(QStringLiteral("origtitle"), i18n("Original Title")));
     f->setFormatType(FieldFormat::FormatTitle);
     coll->addField(f);
 
-    QRegExp origTitleRx(QLatin1String("itemprop=\"alternativeHeadline\"[^>]*>([^<]+)</"));
+    QRegExp origTitleRx(QStringLiteral("itemprop=\"alternativeHeadline\"[^>]*>([^<]+)</"));
     if(str_.contains(origTitleRx)) {
       entry->setField(QStringLiteral("origtitle"), origTitleRx.cap(1));
     }
   }
 
-  QRegExp yearRx(QLatin1String("<a href=\"/lists/m_act%5Byear[^\"]+\"[^>]*>([^<]+)</a"));
+  QRegExp yearRx(QStringLiteral("<a href=\"/lists/m_act%5Byear[^\"]+\"[^>]*>([^<]+)</a"));
   if(str_.contains(yearRx)) {
     entry->setField(QStringLiteral("year"), yearRx.cap(1));
   }
 
-  QRegExp countryRx(QLatin1String("<a href=\"/lists/m_act%5Bcountry[^\"]+\"[^>]*>([^<]+)</a"));
+  QRegExp countryRx(QStringLiteral("<a href=\"/lists/m_act%5Bcountry[^\"]+\"[^>]*>([^<]+)</a"));
   countryRx.setMinimal(true);
   QStringList countries;
   for(int pos = countryRx.indexIn(str_); pos > -1;
@@ -259,7 +263,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
     entry->setField(QStringLiteral("nationality"), countries.join(Tellico::FieldFormat::delimiterString()));
   }
 
-  QRegExp genreRx(QLatin1String("<a href=\"/lists/m_act%5Bgenre[^\"]+\"[^>]*>([^<]+)</a"));
+  QRegExp genreRx(QStringLiteral("<a href=\"/lists/m_act%5Bgenre[^\"]+\"[^>]*>([^<]+)</a"));
   genreRx.setMinimal(true);
   QStringList genres;
   for(int pos = genreRx.indexIn(str_); pos > -1;
@@ -271,7 +275,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
     entry->setField(QStringLiteral("genre"), genres.join(Tellico::FieldFormat::delimiterString()));
   }
 
-  QRegExp directorRx(QLatin1String("<td itemprop=\"director\">(.*)</td"));
+  QRegExp directorRx(QStringLiteral("<td itemprop=\"director\">(.*)</td"));
   directorRx.setMinimal(true);
   if(str_.contains(directorRx)) {
     QString s = directorRx.cap(1);
@@ -279,7 +283,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
     for(int pos = anchorRx.indexIn(s); pos > -1;
             pos = anchorRx.indexIn(s, pos+anchorRx.matchedLength())) {
       QString value = anchorRx.cap(1);
-      if(value != QLatin1String("...")) {
+      if(value != QStringLiteral("...")) {
         directors += value;
       }
     }
@@ -296,7 +300,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
     for(int pos = anchorRx.indexIn(s); pos > -1;
             pos = anchorRx.indexIn(s, pos+anchorRx.matchedLength())) {
       QString value = anchorRx.cap(1);
-      if(value != QLatin1String("...")) {
+      if(value != QStringLiteral("...")) {
         writers += value;
       }
     }
@@ -305,7 +309,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
     }
   }
 
-  QRegExp producerRx(QLatin1String("<td itemprop=\"producer\">(.*)</td"));
+  QRegExp producerRx(QStringLiteral("<td itemprop=\"producer\">(.*)</td"));
   producerRx.setMinimal(true);
   if(str_.contains(producerRx)) {
     QString s = producerRx.cap(1);
@@ -313,7 +317,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
     for(int pos = anchorRx.indexIn(s); pos > -1;
             pos = anchorRx.indexIn(s, pos+anchorRx.matchedLength())) {
       QString value = anchorRx.cap(1);
-      if(value != QLatin1String("...")) {
+      if(value != QStringLiteral("...")) {
         producers += value;
       }
     }
@@ -322,7 +326,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
     }
   }
 
-  QRegExp composerRx(QLatin1String("<td itemprop=\"musicBy\">(.*)</td"));
+  QRegExp composerRx(QStringLiteral("<td itemprop=\"musicBy\">(.*)</td"));
   composerRx.setMinimal(true);
   if(str_.contains(composerRx)) {
     QString s = composerRx.cap(1);
@@ -330,7 +334,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
     for(int pos = anchorRx.indexIn(s); pos > -1;
             pos = anchorRx.indexIn(s, pos+anchorRx.matchedLength())) {
       QString value = anchorRx.cap(1);
-      if(value != QLatin1String("...")) {
+      if(value != QStringLiteral("...")) {
         composers += value;
       }
     }
@@ -347,7 +351,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
     for(int pos = anchorRx.indexIn(s); pos > -1;
             pos = anchorRx.indexIn(s, pos+anchorRx.matchedLength())) {
       QString value = anchorRx.cap(1);
-      if(value != QLatin1String("...")) {
+      if(value != QStringLiteral("...")) {
         actors += value;
       }
     }
@@ -356,37 +360,37 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
     }
   }
 
-  QRegExp runtimeRx(QLatin1String("id=\"runtime\">(\\d+)"));
+  QRegExp runtimeRx(QStringLiteral("id=\"runtime\">(\\d+)"));
   if(str_.contains(runtimeRx)) {
     entry->setField(QStringLiteral("running-time"), runtimeRx.cap(1));
   }
 
-  QRegExp plotRx(QLatin1String("itemprop=\"description\"[^>]*>(.+)</div"));
+  QRegExp plotRx(QStringLiteral("itemprop=\"description\"[^>]*>(.+)</div"));
   plotRx.setMinimal(true);
   if(str_.contains(plotRx)) {
     entry->setField(QStringLiteral("plot"), Tellico::decodeHTML(plotRx.cap(1)));
   } else {
-    plotRx.setPattern(QLatin1String("<meta name=\"description\" content=\"(.+)\""));
+    plotRx.setPattern(QStringLiteral("<meta name=\"description\" content=\"(.+)\""));
     if(str_.contains(plotRx)) {
       entry->setField(QStringLiteral("plot"), Tellico::decodeHTML(plotRx.cap(1)));
     }
   }
 
-  QRegExp mpaaRx(QLatin1String("itemprop=\"contentRating\"[^>]+content=\"MPAA ([^>]+)\""));
+  QRegExp mpaaRx(QStringLiteral("itemprop=\"contentRating\"[^>]+content=\"MPAA ([^>]+)\""));
   mpaaRx.setMinimal(true);
   if(str_.contains(mpaaRx)) {
-    QString value = mpaaRx.cap(1) + QLatin1String(" (USA)");
-//    entry->setField(QLatin1String("certification"), i18n(value.toUtf8()));
+    QString value = mpaaRx.cap(1) + QStringLiteral(" (USA)");
+//    entry->setField(QStringLiteral("certification"), i18n(value.toUtf8()));
     entry->setField(QStringLiteral("certification"), value);
   }
 
   QString cover;
-  QRegExp coverRx(QLatin1String("<a class=\"popupBigImage\"[^>]+>\\s*<img.*src=\"([^\"]+)\""));
+  QRegExp coverRx(QStringLiteral("<a class=\"popupBigImage\"[^>]+>\\s*<img.*src=\"([^\"]+)\""));
   coverRx.setMinimal(true);
   if(str_.contains(coverRx)) {
     cover = coverRx.cap(1);
   } else {
-    coverRx.setPattern(QLatin1String("<meta property=\"vk:image\" content=\"(.+)\""));
+    coverRx.setPattern(QStringLiteral("<meta property=\"vk:image\" content=\"(.+)\""));
     if(str_.contains(coverRx)) {
       cover = coverRx.cap(1);
     }
