@@ -28,7 +28,6 @@
 #include "../translators/tellico_xml.h"
 #include "../translators/xslthandler.h"
 #include "../translators/tellicoimporter.h"
-#include "../translators/xmlimporter.h"
 #include "../utils/guiproxy.h"
 #include "../gui/lineedit.h"
 #include "../gui/combobox.h"
@@ -52,6 +51,7 @@
 #include <QGridLayout>
 #include <QFile>
 #include <QUrlQuery>
+#include <QDomDocument>
 
 namespace {
   // 7090 was the old default port, but that was just because LoC used it
@@ -289,10 +289,14 @@ void SRUFetcher::slotComplete(KJob*) {
   const QString result = QString::fromUtf8(data.constData(), data.size());
 
   // first check for SRU errors
-  const QString& diag = XML::nsZingDiag;
-  Import::XMLImporter xmlImporter(result);
-  QDomDocument dom = xmlImporter.domDocument();
+  QDomDocument dom;
+  if(!dom.setContent(result, true /*namespace*/)) {
+    myWarning() << "server did not return valid XML.";
+    stop();
+    return;
+  }
 
+  const QString& diag = XML::nsZingDiag;
   QDomNodeList diagList = dom.elementsByTagNameNS(diag, QStringLiteral("diagnostic"));
   for(int i = 0; i < diagList.count(); ++i) {
     QDomElement elem = diagList.item(i).toElement();
@@ -516,9 +520,9 @@ SRUFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const SRUFetcher* fetch
   QLabel* label = new QLabel(i18n("Hos&t: "), optionsWidget());
   l->addWidget(label, ++row, 0);
   m_hostEdit = new GUI::LineEdit(optionsWidget());
-  connect(m_hostEdit, SIGNAL(textChanged(const QString&)), SLOT(slotSetModified()));
-  connect(m_hostEdit, SIGNAL(textChanged(const QString&)), SIGNAL(signalName(const QString&)));
-  connect(m_hostEdit, SIGNAL(textChanged(const QString&)), SLOT(slotCheckHost()));
+  connect(m_hostEdit, SIGNAL(textChanged(QString)), SLOT(slotSetModified()));
+  connect(m_hostEdit, SIGNAL(textChanged(QString)), SIGNAL(signalName(QString)));
+  connect(m_hostEdit, SIGNAL(textChanged(QString)), SLOT(slotCheckHost()));
   l->addWidget(m_hostEdit, row, 1);
   QString w = i18n("Enter the host name of the server.");
   label->setWhatsThis(w);
@@ -541,7 +545,7 @@ SRUFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const SRUFetcher* fetch
   label = new QLabel(i18n("Path: "), optionsWidget());
   l->addWidget(label, ++row, 0);
   m_pathEdit = new GUI::LineEdit(optionsWidget());
-  connect(m_pathEdit, SIGNAL(textChanged(const QString&)), SLOT(slotSetModified()));
+  connect(m_pathEdit, SIGNAL(textChanged(QString)), SLOT(slotSetModified()));
   l->addWidget(m_pathEdit, row, 1);
   w = i18n("Enter the path to the database used by the server.");
   label->setWhatsThis(w);
