@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright (C) 2013 Robby Stephenson <robby@periapsis.org>
+    Copyright (C) 2013-2019 Robby Stephenson <robby@periapsis.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -44,6 +44,8 @@
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonValue>
+#include <QRegularExpression>
+#include <QTimer>
 
 namespace {
   static const char* VNDB_HOSTNAME = "api.vndb.org";
@@ -58,6 +60,9 @@ VNDBFetcher::VNDBFetcher(QObject* parent_)
 }
 
 VNDBFetcher::~VNDBFetcher() {
+  if(m_socket && m_isConnected) {
+    m_socket->disconnectFromHost();
+  }
   delete m_socket;
   m_socket = nullptr;
 }
@@ -82,10 +87,12 @@ void VNDBFetcher::search() {
   m_data.clear();
 
   if(!m_socket) {
+    // see https://wiki.qt.io/New_Signal_Slot_Syntax#Overload for why this is necessary
+    void (QTcpSocket::* errorSignal)(QAbstractSocket::SocketError) = &QAbstractSocket::error;
     m_socket = new QTcpSocket(this);
-    connect(m_socket, SIGNAL(readyRead()), SLOT(slotRead()));
-    connect(m_socket, SIGNAL(stateChanged(QAbstractSocket::SocketState)), SLOT(slotState()));
-    connect(m_socket, SIGNAL(error(QAbstractSocket::SocketError)), SLOT(slotError()));
+    QObject::connect(m_socket, &QTcpSocket::readyRead,    this, &VNDBFetcher::slotRead);
+    QObject::connect(m_socket, &QTcpSocket::stateChanged, this, &VNDBFetcher::slotState);
+    QObject::connect(m_socket, errorSignal,               this, &VNDBFetcher::slotError);
   }
   if(!m_isConnected) {
     m_socket->connectToHost(QLatin1String(VNDB_HOSTNAME), VNDB_PORT);
@@ -93,7 +100,7 @@ void VNDBFetcher::search() {
 
   //the client ver only wants digits, I think?
   QString clientVersion(QStringLiteral(TELLICO_VERSION));
-  clientVersion.remove(QRegExp(QLatin1String("[^0-9.]")));
+  clientVersion.remove(QRegularExpression(QStringLiteral("[^0-9.]")));
 
   QByteArray login = "login {"
                              "\"protocol\":1,"
@@ -112,10 +119,10 @@ void VNDBFetcher::search() {
     }
   }
 
-  QByteArray get = "get vn basic,details ";
+  QByteArray get("get vn basic,details ");
   switch(request().key) {
     case Title:
-      get += "(title ~ \"" + request().value.toUtf8() + "\")";
+      get += "(search ~ \"" + request().value.toUtf8() + "\")";
       break;
 
     default:
@@ -123,7 +130,8 @@ void VNDBFetcher::search() {
       return;
   }
 
-//  myDebug() << "get:" << get;
+  m_state = GetVN;
+//  myDebug() << get << m_state;
   get.append(0x04);
   m_socket->write(get);
 }
@@ -133,11 +141,6 @@ void VNDBFetcher::stop() {
     return;
   }
   m_started = false;
-  if(m_socket && m_socket->isValid()) {
-//    myDebug() << "disconnecting";
-    m_socket->disconnectFromHost();
-    m_state = PreLogin;
-  }
   emit signalDone(this);
 }
 
@@ -148,6 +151,24 @@ Tellico::Data::EntryPtr VNDBFetcher::fetchEntryHook(uint uid_) {
     return Data::EntryPtr();
   }
 
+  // clear past data
+  m_data.clear();
+  // don't need anything for the "details" group
+  QByteArray get("get release basic,producers ");
+  get += "(vn = " + entry->field(QStringLiteral("vn-id")).toLatin1()
+       + " and patch = false and type = \"complete\")";
+
+  m_state = GetRelease;
+//  myDebug() << get << m_state;
+  get.append(0x04);
+  m_socket->write(get);
+  // 5 sec is long enough?
+  m_socket->waitForReadyRead(5000);
+
+  if(verifyData()) {
+    parseReleaseResults(entry);
+  }
+
   // image might still be a URL
   const QString image_id = entry->field(QStringLiteral("cover"));
   if(image_id.contains(QLatin1Char('/'))) {
@@ -158,6 +179,13 @@ Tellico::Data::EntryPtr VNDBFetcher::fetchEntryHook(uint uid_) {
     // empty image ID is ok
     entry->setField(QStringLiteral("cover"), id);
   }
+  // clear the placeholder fields
+  entry->setField(QStringLiteral("vn-id"), QString());
+
+  if(m_socket && m_socket->isValid()) {
+    m_socket->disconnectFromHost();
+    m_state = PreLogin;
+  }
 
   return entry;
 }
@@ -170,60 +198,64 @@ Tellico::Fetch::FetchRequest VNDBFetcher::updateRequest(Data::EntryPtr entry_) {
   return FetchRequest();
 }
 
-void VNDBFetcher::slotComplete() {
+bool VNDBFetcher::verifyData() {
   if(m_data.isEmpty()) {
     myDebug() << "no data";
-    stop();
-    return;
+    return false;
   }
 
-  QByteArray data = m_data;
   // remove the last hex character
-  data.chop(1);
+  m_data.chop(1);
 
-  if(data.startsWith("error")) { //krazy:exclude=strings
-    QJsonDocument doc = QJsonDocument::fromJson(data.mid(5));
+  if(m_data.startsWith("error")) { //krazy:exclude=strings
+    QJsonDocument doc = QJsonDocument::fromJson(m_data.mid(5));
     QVariantMap result = doc.object().toVariantMap();
     if(result.contains(QStringLiteral("msg"))) {
-      myDebug() << result.value(QStringLiteral("msg")).toString();
+      myDebug() << "Data error:" << result.value(QStringLiteral("msg")).toString();
       message(result.value(QStringLiteral("msg")).toString(), MessageHandler::Error);
     }
-    stop();
-    return;
+    return false;
   }
 
-//  myDebug() << data;
+//  myDebug() << m_data;
   if(m_state == PreLogin) {
-    if(data.startsWith("ok")) { //krazy:exclude=strings
+    if(m_data.startsWith("ok")) { //krazy:exclude=strings
       m_state = PostLogin;
       m_data.clear(); // reset data buffer
-    } else {
-      stop();
+      return true;
     }
-    return;
+    // some sort of error
+    myDebug() << "Failed to login properly...";
+    return false;
   }
 
-  if(!data.startsWith("results")) { //krazy:exclude=strings
-    myDebug() << "Expecting results!";
-    stop();
-    return;
+  if(!m_data.startsWith("results")) { //krazy:exclude=strings
+    myDebug() << "Expecting results and didn't get them!";
+    return false;
   }
 
-  data = data.mid(7);
+  // chop off "results"
+  m_data = m_data.mid(7);
+  return true;
+}
 
+void VNDBFetcher::parseVNResults() {
+  if(!verifyData()) {
+    return;
+  }
 #if 0
   myWarning() << "Remove debug from vndbfetcher.cpp";
   QFile f(QString::fromLatin1("/tmp/vndbtest.json"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
     t.setCodec("UTF-8");
-    t << data;
+    t << m_data;
   }
   f.close();
 #endif
 
   QJsonParseError jsonError;
-  QJsonDocument doc = QJsonDocument::fromJson(data, &jsonError);
+  QJsonDocument doc = QJsonDocument::fromJson(m_data, &jsonError);
   if(doc.isNull()) {
     myDebug() << "null JSON document:" << jsonError.errorString();
     message(jsonError.errorString(), MessageHandler::Error);
@@ -239,13 +271,16 @@ void VNDBFetcher::slotComplete() {
   }
 
   Data::CollPtr coll(new Data::GameCollection(true));
+  // placeholder for vn id, to be removed later
+  Data::FieldPtr f1(new Data::Field(QStringLiteral("vn-id"), QString(), Data::Field::Number));
+  coll->addField(f1);
   // add new fields
-  if(optionalFields().contains(QLatin1String("origtitle"))) {
+  if(optionalFields().contains(QStringLiteral("origtitle"))) {
     Data::FieldPtr f(new Data::Field(QStringLiteral("origtitle"), i18n("Original Title")));
     f->setFormatType(FieldFormat::FormatTitle);
     coll->addField(f);
   }
-  if(optionalFields().contains(QLatin1String("alias"))) {
+  if(optionalFields().contains(QStringLiteral("alias"))) {
     Data::FieldPtr f(new Data::Field(QStringLiteral("alias"), i18n("Alias")));
     f->setFlags(Data::Field::AllowMultiple);
     f->setFormatType(FieldFormat::FormatTitle);
@@ -263,14 +298,15 @@ void VNDBFetcher::slotComplete() {
 
     Data::EntryPtr entry(new Data::Entry(coll));
     entry->setField(QStringLiteral("title"), mapValue(resultMap, "title"));
+    entry->setField(QStringLiteral("vn-id"), mapValue(resultMap, "id"));
     entry->setField(QStringLiteral("year"), mapValue(resultMap, "released").left(4));
     entry->setField(QStringLiteral("genre"), i18n("Visual Novel"));
     entry->setField(QStringLiteral("description"), mapValue(resultMap, "description"));
     entry->setField(QStringLiteral("cover"), mapValue(resultMap, "image"));
-    if(optionalFields().contains(QLatin1String("origtitle"))) {
+    if(optionalFields().contains(QStringLiteral("origtitle"))) {
       entry->setField(QStringLiteral("origtitle"), mapValue(resultMap, "original"));
     }
-    if(optionalFields().contains(QLatin1String("alias"))) {
+    if(optionalFields().contains(QStringLiteral("alias"))) {
       const QString aliases = mapValue(resultMap, "aliases");
       entry->setField(QStringLiteral("alias"), aliases.split(QStringLiteral("\n")).join(FieldFormat::delimiterString()));
     }
@@ -286,6 +322,53 @@ void VNDBFetcher::slotComplete() {
   stop();
 }
 
+void VNDBFetcher::parseReleaseResults(Data::EntryPtr entry_) {
+#if 0
+  myWarning() << "Remove debug2 from vndbfetcher.cpp";
+  QFile f(QString::fromLatin1("/tmp/vndb-release.json"));
+  if(f.open(QIODevice::WriteOnly)) {
+    QTextStream t(&f);
+    t.setCodec("UTF-8");
+    t << m_data;
+  }
+  f.close();
+#endif
+
+  QJsonParseError jsonError;
+  QJsonDocument doc = QJsonDocument::fromJson(m_data, &jsonError);
+  if(doc.isNull()) {
+    myDebug() << "null JSON document:" << jsonError.errorString();
+    message(jsonError.errorString(), MessageHandler::Error);
+    return;
+  }
+  QVariantMap topResultMap = doc.object().toVariantMap();
+  QVariantList resultList = topResultMap.value(QStringLiteral("items")).toList();
+  if(resultList.isEmpty()) {
+    myDebug() << "no results";
+    return;
+  }
+
+  // only work on the first release item
+  const QVariantMap resultMap = resultList.at(0).toMap();
+
+  QStringList pubs, devs;
+  QVariantList producerList = resultMap.value(QStringLiteral("producers")).toList();
+  foreach(const QVariant& producerObject, producerList) {
+    const QVariantMap producerMap = producerObject.toMap();
+    if(producerMap.value(QStringLiteral("publisher")) == true) {
+      pubs += mapValue(producerMap, "name");
+    }
+    if(producerMap.value(QStringLiteral("developer")) == true) {
+      devs += mapValue(producerMap, "name");
+    }
+  }
+  entry_->setField(QStringLiteral("publisher"), pubs.join(FieldFormat::delimiterString()));
+  entry_->setField(QStringLiteral("developer"), devs.join(FieldFormat::delimiterString()));
+
+  // update release year
+  entry_->setField(QStringLiteral("year"), mapValue(resultMap, "released").left(4));
+}
+
 void VNDBFetcher::slotState() {
   if(!m_socket) {
     return;
@@ -295,14 +378,13 @@ void VNDBFetcher::slotState() {
   } else if(m_socket->state() == QAbstractSocket::UnconnectedState) {
     m_isConnected = false;
   }
-//  myDebug() << "state" << m_socket->state();
 }
 
 void VNDBFetcher::slotError() {
   if(!m_socket) {
     return;
   }
-  myDebug() << m_socket->errorString();
+  myDebug() << "Socket error:" << m_socket->errorString();
 }
 
 void VNDBFetcher::slotRead() {
@@ -310,21 +392,34 @@ void VNDBFetcher::slotRead() {
 
   // check the last character, if it's not the hex character, continue waiting
   if(m_socket->atEnd() && m_data.endsWith(0x04)) {
-    slotComplete();
+    switch(m_state) {
+      case PreLogin:
+        verifyData();
+        break;
+      case GetVN:
+        // necessary for passing unit test
+        QTimer::singleShot(0, this, SLOT(parseVNResults()));
+        break;
+      case GetRelease:
+        // handled asynch
+        break;
+      case PostLogin:
+      default:
+        myDebug() << "Unexpected state in slotRead";
+    }
   }
 }
 
-
 Tellico::Fetch::ConfigWidget* VNDBFetcher::configWidget(QWidget* parent_) const {
   return new VNDBFetcher::ConfigWidget(parent_, this);
 }
 
 QString VNDBFetcher::defaultName() {
-  return QStringLiteral("Visual Novel Database"); // no translation
+  return QStringLiteral("The Visual Novel Database"); // no translation
 }
 
 QString VNDBFetcher::defaultIcon() {
-  return favIcon("http://www.vndb.org");
+  return favIcon("https://vndb.org");
 }
 
 Tellico::StringHash VNDBFetcher::allOptionalFields() {
