@@ -99,32 +99,31 @@ void ImageJob::slotStart() {
 }
 
 void ImageJob::getJobResult(KJob* job_) {
-  if(!job_ || job_->error()) {
+  KIO::StoredTransferJob* getJob = qobject_cast<KIO::StoredTransferJob*>(job_);
+  if(!getJob || getJob->error()) {
     // error handling for subjob is handled by KCompositeJob
     setErrorText(i18n("Tellico is unable to load the image - %1.", m_url.toDisplayString()));
     return;
   }
-  KIO::StoredTransferJob* getJob = qobject_cast<KIO::StoredTransferJob*>(job_);
-  if(getJob) {
-    // If we used the Image() c'tor that take a bytearray of data, I'm not sure how to
-    // figure out the image format directly. Instead, write into a buffer and use QImageReader
-    QByteArray data = getJob->data();
-    QBuffer buffer(&data);
-    buffer.open(QIODevice::ReadOnly);
-    m_image = Data::Image(data, QString::fromLatin1(QImageReader::imageFormat(&buffer)), m_id);
-    if(m_image.isNull()) {
-      setError(KIO::ERR_UNKNOWN);
-      m_image = Data::Image::null;
-    } else {
-      // if we can't write the input format, then change to one we can
-      m_image.setFormat(Data::Image::outputFormat(m_image.format()));
-      if(m_id.isEmpty()) {
-        m_image.calculateID();
-      }
-      if(m_linkOnly) {
-        m_image.setLinkOnly(true);
-        m_image.setID(m_url.url());
-      }
+
+  // If we used the Image() c'tor that take a bytearray of data, I'm not sure how to
+  // figure out the image format directly. Instead, write into a buffer and use QImageReader
+  QByteArray data = getJob->data();
+  QBuffer buffer(&data);
+  buffer.open(QIODevice::ReadOnly);
+  m_image = Data::Image(data, QString::fromLatin1(QImageReader::imageFormat(&buffer)), m_id);
+  if(m_image.isNull()) {
+    setError(KIO::ERR_UNKNOWN);
+    m_image = Data::Image::null;
+  } else {
+    // if we can't write the input format, then change to one we can
+    m_image.setFormat(Data::Image::outputFormat(m_image.format()));
+    if(m_id.isEmpty()) {
+      m_image.calculateID();
+    }
+    if(m_linkOnly) {
+      m_image.setLinkOnly(true);
+      m_image.setID(m_url.url());
     }
   }
   emitResult();
