@@ -70,6 +70,7 @@
 #include "gui/lineedit.h"
 #include "gui/statusbar.h"
 #include "gui/tabwidget.h"
+#include "gui/dockwidget.h"
 #include "utils/cursorsaver.h"
 #include "utils/guiproxy.h"
 #include "tellico_debug.h"
@@ -94,10 +95,11 @@
 #include <KActionMenu>
 #include <KAboutData>
 #include <KFileWidget>
+#include <KDualAction>
+#include <KXMLGUIFactory>
 
 #include <QApplication>
 #include <QUndoStack>
-#include <QSplitter>
 #include <QAction>
 #include <QSignalMapper>
 #include <QTimer>
@@ -218,6 +220,7 @@ void MainWindow::slotInit() {
 
   m_toggleEntryEditor->setChecked(Config::showEditWidget());
   slotToggleEntryEditor();
+  slotToggleLayoutLock(Config::lockLayout());
 
   initConnections();
   connect(ImageFactory::self(), SIGNAL(imageLocationMismatch()),
@@ -634,12 +637,22 @@ void MainWindow::initActions() {
   setStandardToolBarMenuEnabled(true);
   createStandardStatusBarAction();
 
-  m_toggleGroupWidget = new KToggleAction(i18n("Show Grou&p View"), this);
-  m_toggleGroupWidget->setToolTip(i18n("Enable/disable the group view"));
-  connect(m_toggleGroupWidget, SIGNAL(triggered()), SLOT(slotToggleGroupWidget()));
-  actionCollection()->addAction(QStringLiteral("toggle_group_widget"), m_toggleGroupWidget);
+  KDualAction* dualAction = new KDualAction(this);
+  connect(dualAction, SIGNAL(activeChanged(bool)), SLOT(slotToggleLayoutLock(bool)));
+  dualAction->setActiveText(i18n("Unlock Layout"));
+  dualAction->setActiveToolTip(i18n("Unlock the window's layout"));
+  dualAction->setActiveIcon(QIcon::fromTheme(QStringLiteral("object-unlocked")));
+  dualAction->setInactiveText(i18n("Lock Layout"));
+  dualAction->setInactiveToolTip(i18n("Lock the window's layout"));
+  dualAction->setInactiveIcon(QIcon::fromTheme(QStringLiteral("object-locked")));
+  actionCollection()->addAction(QStringLiteral("lock_layout"), dualAction);
 
-  m_toggleEntryEditor = new KToggleAction(i18n("Show Entry &Editor"), this);
+  action = actionCollection()->addAction(QStringLiteral("reset_layout"), this, SLOT(slotResetLayout()));
+  action->setText(i18n("Reset Layout"));
+  action->setToolTip(i18n("Reset the window's layout"));
+  action->setIcon(QIcon::fromTheme(QStringLiteral("resetview")));
+
+  m_toggleEntryEditor = new KToggleAction(i18n("Entry &Editor"), this);
   connect(m_toggleEntryEditor, SIGNAL(triggered()), SLOT(slotToggleEntryEditor()));
   m_toggleEntryEditor->setToolTip(i18n("Enable/disable the editor"));
   actionCollection()->addAction(QStringLiteral("toggle_edit_widget"), m_toggleEntryEditor);
@@ -667,8 +680,8 @@ void MainWindow::initActions() {
   m_entryGrouping = new KSelectAction(i18n("&Group Selection"), this);
   m_entryGrouping->setToolTip(i18n("Change the grouping of the collection"));
   // really bad hack, but I can't figure out how to make the combobox resize when the contents change
-  // see note in slotChangeGrouping() - so ensure its at least a little bigger
-  m_entryGrouping->addAction(QStringLiteral("                         "));
+  // see note in slotUpdateCollectionToolBar() - found a hackier solution
+//  m_entryGrouping->addAction(QString(50, QLatin1Char(' ')));
   connect(m_entryGrouping, SIGNAL(triggered(int)), SLOT(slotChangeGrouping()));
   actionCollection()->addAction(QStringLiteral("change_entry_grouping"), m_entryGrouping);
 
@@ -696,13 +709,7 @@ void MainWindow::initActions() {
   widgetAction->setProperty("isShortcutConfigurable", false);
   actionCollection()->addAction(QStringLiteral("quick_filter"), widgetAction);
 
-  setupGUI(Keys | ToolBar);
-#ifdef UIFILE
-  myWarning() << "call!";
-  createGUI(UIFILE);
-#else
-  createGUI();
-#endif
+  // final GUI setup is in initView()
 }
 
 #undef mimeIcon
@@ -737,21 +744,23 @@ void MainWindow::initView() {
   // initialize the image factory before the entry models are created
   ImageFactory::init();
 
-  m_split = new QSplitter(Qt::Horizontal, this);
-  setCentralWidget(m_split);
+  m_entryView = new EntryView(this);
+  connect(m_entryView, SIGNAL(signalAction(const QUrl&)),
+          SLOT(slotURLAction(const QUrl&)));
+  m_entryView->view()->setWhatsThis(i18n("<qt>The <i>Entry View</i> shows a formatted view of the entry's contents.</qt>"));
 
-  m_viewTabs = new GUI::TabWidget(m_split);
-  m_viewTabs->setTabBarHidden(true);
-  m_viewTabs->setDocumentMode(true);
-  m_groupView = new GroupView(m_viewTabs);
-  Controller::self()->addObserver(m_groupView);
-  m_viewTabs->addTab(m_groupView, QIcon::fromTheme(QStringLiteral("folder")), i18n("Groups"));
-  m_groupView->setWhatsThis(i18n("<qt>The <i>Group View</i> sorts the entries into groupings "
-                                    "based on a selected field.</qt>"));
+  // trick to make sure the group views always extend along the entire left or right side
+  // using QMainWindow::setCorner does not seem to work
+  // https://wiki.qt.io/Technical_FAQ#Is_it_possible_for_either_the_left_or_right_dock_areas_to_have_full_height_of_their_side_rather_than_having_the_bottom_take_the_full_width.3F
+  m_dummyWindow = new QMainWindow(this);
+  m_dummyWindow->setCentralWidget(m_entryView->view());
+  m_dummyWindow->setWindowFlags(Qt::Widget);
+  setCentralWidget(m_dummyWindow);
 
-  m_rightSplit = new QSplitter(Qt::Vertical, m_split);
+  m_collectionViewDock = new GUI::DockWidget(i18n("Collection View"), m_dummyWindow);
+  m_collectionViewDock->setObjectName(QStringLiteral("collection_dock"));
 
-  m_viewStack = new ViewStack(m_rightSplit);
+  m_viewStack = new ViewStack(this);
 
   m_detailedView = m_viewStack->listView();
   Controller::self()->addObserver(m_detailedView);
@@ -768,17 +777,35 @@ void MainWindow::initView() {
   m_iconView->setWhatsThis(i18n("<qt>The <i>Icon View</i> shows each entry in the collection or group using "
                                 "an icon, which may be an image in the entry.</qt>"));
 
-  m_entryView = new EntryView(m_rightSplit);
-  connect(m_entryView, SIGNAL(signalAction(const QUrl&)),
-          SLOT(slotURLAction(const QUrl&)));
-  m_entryView->view()->setWhatsThis(i18n("<qt>The <i>Entry View</i> shows a formatted view of the entry's contents.</qt>"));
+  m_collectionViewDock->setWidget(m_viewStack);
+  m_dummyWindow->addDockWidget(Qt::TopDockWidgetArea, m_collectionViewDock);
+  actionCollection()->addAction(QStringLiteral("toggle_column_widget"), m_collectionViewDock->toggleViewAction());
 
-  setMinimumWidth(MAIN_WINDOW_MIN_WIDTH);
+  m_groupViewDock = new GUI::DockWidget(i18n("Group View"), this);
+  m_groupViewDock->setObjectName(QStringLiteral("group_dock"));
+  m_groupViewDock->setAllowedAreas(Qt::DockWidgetAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea));
+
+  m_viewTabs = new GUI::TabWidget(this);
+  m_viewTabs->setTabBarHidden(true);
+  m_viewTabs->setDocumentMode(true);
+  m_groupView = new GroupView(m_viewTabs);
+  Controller::self()->addObserver(m_groupView);
+  m_viewTabs->addTab(m_groupView, QIcon::fromTheme(QStringLiteral("folder")), i18n("Groups"));
+  m_groupView->setWhatsThis(i18n("<qt>The <i>Group View</i> sorts the entries into groupings "
+                                    "based on a selected field.</qt>"));
+  m_groupViewDock->setWidget(m_viewTabs);
+  addDockWidget(Qt::LeftDockWidgetArea, m_groupViewDock);
+  actionCollection()->addAction(QStringLiteral("toggle_group_widget"), m_groupViewDock->toggleViewAction());
 
   EntrySelectionModel* proxySelect = new EntrySelectionModel(m_iconView->model(),
                                                              m_detailedView->selectionModel(),
                                                              this);
   m_iconView->setSelectionModel(proxySelect);
+
+  setMinimumWidth(MAIN_WINDOW_MIN_WIDTH);
+  // setting up GUI now rather than in initActions
+  setupGUI(Keys | ToolBar);
+  createGUI();
 }
 
 void MainWindow::initConnections() {
@@ -857,9 +884,11 @@ void MainWindow::initFileOpen(bool nofile_) {
 void MainWindow::saveOptions() {
   KConfigGroup config(KSharedConfig::openConfig(), "Main Window Options");
   saveMainWindowSettings(config);
+  config.writeEntry(QStringLiteral("Central Dock State"), m_dummyWindow->saveState());
 
-  Config::setShowGroupWidget(m_toggleGroupWidget->isChecked());
   Config::setShowEditWidget(m_toggleEntryEditor->isChecked());
+  // check any single dock widget, they all get locked together
+  Config::setLockLayout(m_groupViewDock->isLocked());
 
   KConfigGroup filesConfig(KSharedConfig::openConfig(), "Recent Files");
   m_fileOpenRecent->saveEntries(filesConfig);
@@ -867,10 +896,6 @@ void MainWindow::saveOptions() {
     Config::setLastOpenFile(Data::Document::self()->URL().url());
   }
 
-  if(!m_groupView->isHidden()) {
-    Config::setMainSplitterSizes(m_split->sizes());
-  }
-  Config::setSecondarySplitterSizes(m_rightSplit->sizes());
   Config::setViewWidget(m_viewStack->currentWidget());
 
   // historical reasons
@@ -990,29 +1015,13 @@ void MainWindow::saveCollectionOptions(Tellico::Data::CollPtr coll_) {
 void MainWindow::readOptions() {
   KConfigGroup mainWindowConfig(KSharedConfig::openConfig(), "Main Window Options");
   applyMainWindowSettings(mainWindowConfig);
-
-  QList<int> splitList = Config::mainSplitterSizes();
-  if(splitList.empty()) {
-    const int tw = width()/3;
-    splitList << tw << 2*tw;
-  }
-  m_split->setSizes(splitList);
-
-  splitList = Config::secondarySplitterSizes();
-  if(splitList.empty()) {
-    const int th = 2*width()/5;
-    splitList << th << th;
-  }
-  m_rightSplit->setSizes(splitList);
+  m_dummyWindow->restoreState(mainWindowConfig.readEntry(QStringLiteral("Central Dock State"), QByteArray()));
 
   m_viewStack->setCurrentWidget(Config::viewWidget());
   m_iconView->setMaxAllowedIconWidth(Config::maxIconSize());
 
   connect(toolBar(QStringLiteral("collectionToolBar")), SIGNAL(iconSizeChanged(const QSize&)), SLOT(slotUpdateToolbarIcons()));
 
-  m_toggleGroupWidget->setChecked(Config::showGroupWidget());
-  slotToggleGroupWidget();
-
   // initialize the recent file list
   KConfigGroup filesConfig(KSharedConfig::openConfig(), "Recent Files");
   m_fileOpenRecent->loadEntries(filesConfig);
@@ -1022,12 +1031,7 @@ void MainWindow::readOptions() {
   Qt::SortOrder sortOrder = Config::groupViewSortAscending() ? Qt::AscendingOrder : Qt::DescendingOrder;
   m_groupView->setSorting(sortOrder, sortRole);
 
-  bool useBraces = Config::useBraces();
-  if(useBraces) {
-    BibtexHandler::s_quoteStyle = BibtexHandler::BRACES;
-  } else {
-    BibtexHandler::s_quoteStyle = BibtexHandler::QUOTES;
-  }
+  BibtexHandler::s_quoteStyle = Config::useBraces() ? BibtexHandler::BRACES : BibtexHandler::QUOTES;
 
   // Don't read any options for the edit dialog here, since it's not yet initialized.
   // Put them in init()
@@ -1425,20 +1429,6 @@ void MainWindow::slotEditDeselect() {
   Controller::self()->slotUpdateSelection(Data::EntryList());
 }
 
-void MainWindow::slotToggleGroupWidget() {
-  if(m_toggleGroupWidget->isChecked()) {
-    m_viewTabs->show();
-    // if width was set to zero, choose a default width
-    if(m_viewTabs->width() == 0) {
-      QList<int> widths = m_split->sizes();
-      widths[0] = m_viewTabs->minimumSizeHint().width();
-      m_split->setSizes(widths);
-    }
-  } else {
-    m_viewTabs->hide();
-  }
-}
-
 void MainWindow::slotToggleEntryEditor() {
   if(m_toggleEntryEditor->isChecked()) {
     m_editDialog->show();
@@ -1581,23 +1571,31 @@ void MainWindow::slotUpdateCollectionToolBar(Tellico::Data::CollPtr coll_) {
     }
   }
 
+  const QStringList titles = groupMap.values();
+  if(titles == m_entryGrouping->items()) {
+    // no need to update anything
+    return;
+  }
   const QStringList names = groupMap.keys();
   int index = names.indexOf(current);
   if(index == -1) {
     current = names[0];
     index = 0;
   }
-  const QStringList titles = groupMap.values();
   m_entryGrouping->setItems(titles);
   m_entryGrouping->setCurrentItem(index);
   // in case the current grouping field get modified to be non-grouping...
   m_groupView->setGroupField(current); // don't call slotChangeGrouping() since it adds an undo item
 
-  // I have no idea how to get the combobox to update its size
+  // TODO::I have no idea how to get the combobox to update its size
+  // this is the hackiest of hacks, taken from KXmlGuiWindow::saveNewToolbarConfig()
+  // the window flickers as toolbar resizes, unavoidable?
+  // crashes if removeCLient//addClient is called here, need to do later in event loop
+  QTimer::singleShot(0, this, &MainWindow::guiFactoryReset);
 }
 
 void MainWindow::slotChangeGrouping() {
-  QString title = m_entryGrouping->currentText();
+  const QString title = m_entryGrouping->currentText();
 
   QString groupName = Kernel::self()->fieldNameByTitle(title);
   if(groupName.isEmpty()) {
@@ -2161,6 +2159,7 @@ void MainWindow::slotGroupLabelActivated() {
       QComboBox* combo = ::qobject_cast<QComboBox*>(container); //krazy:exclude=qclasses
       if(combo) {
         combo->showPopup();
+        break;
       }
     }
   }
@@ -2362,3 +2361,24 @@ void MainWindow::slotToggleMenuBarVisibility() {
   QMenuBar* mb = menuBar();
   mb->isHidden() ? mb->show() : mb->hide();
 }
+
+void MainWindow::slotToggleLayoutLock(bool lock_) {
+  m_groupViewDock->setLocked(lock_);
+  m_collectionViewDock->setLocked(lock_);
+}
+
+void MainWindow::slotResetLayout() {
+  removeDockWidget(m_groupViewDock);
+  addDockWidget(Qt::LeftDockWidgetArea, m_groupViewDock);
+  m_groupViewDock->show();
+
+  m_dummyWindow->removeDockWidget(m_collectionViewDock);
+  m_dummyWindow->addDockWidget(Qt::TopDockWidgetArea, m_collectionViewDock);
+  m_collectionViewDock->show();
+}
+
+void MainWindow::guiFactoryReset() {
+  guiFactory()->removeClient(this);
+  guiFactory()->reset();
+  guiFactory()->addClient(this);
+}
