@@ -44,7 +44,7 @@ class KRecentFilesAction;
 class KActionMenu;
 
 class QCloseEvent;
-class QSplitter;
+class QDockWidget;
 class QSignalMapper;
 
 namespace Tellico {
@@ -52,6 +52,7 @@ namespace Tellico {
   namespace GUI {
     class LineEdit;
     class TabWidget;
+    class DockWidget;
   }
   class Controller;
   class ViewStack;
@@ -200,10 +201,6 @@ public Q_SLOTS:
    * Deselects all the entries in the collection.
    */
   void slotEditDeselect();
-  /**
-   * Toggles the group widget.
-   */
-  void slotToggleGroupWidget();
   /**
    * Toggles the edit widget.
    */
@@ -333,7 +330,7 @@ private:
   bool querySaveModified();
 
   /**
-   * Called before the window is closed, either by the user or indirectely by the
+   * Called before the window is closed, either by the user or indirectly by the
    * session manager.
    *
    * The purpose of this function is to prepare the window in a way that it is safe to close it,
@@ -460,6 +457,9 @@ private Q_SLOTS:
    * Toggle menubar visibility
    */
   void slotToggleMenuBarVisibility();
+  void slotToggleLayoutLock(bool lock);
+  void slotResetLayout();
+  void guiFactoryReset();
 
 private:
   void importFile(Import::Format format, const QList<QUrl>& kurls);
@@ -479,16 +479,14 @@ private:
   QAction* m_updateAll;
   QAction* m_checkInEntry;
   QAction* m_checkOutEntry;
-  KToggleAction* m_toggleGroupWidget;
   KToggleAction* m_toggleEntryEditor;
 
   KSelectAction* m_entryGrouping;
   GUI::LineEdit* m_quickFilter;
 
-  // m_split is used between the stuff on the left and stuff on the right
-  QSplitter* m_split;
-  // m_leftSplit is used between detailed view and entry view
-  QSplitter* m_rightSplit;
+  QMainWindow* m_dummyWindow;
+  GUI::DockWidget* m_groupViewDock;
+  GUI::DockWidget* m_collectionViewDock;
 
   Tellico::StatusBar* m_statusBar;
 
