@@ -27,6 +27,8 @@
 
 #include <QObject>
 
+#include "../datavectors.h"
+
 class CollectionTest : public QObject {
 Q_OBJECT
 
@@ -46,7 +48,14 @@ private Q_SLOTS:
   void testMergeFields();
   void testAppendCollection();
   void testMergeCollection();
+  void testBookMatch();
   void testMergeBenchmark();
+  void testMatchScore();
+  void testMatchScore_data();
+
+private:
+  Tellico::Data::CollPtr m_coll;
+  Tellico::Data::EntryPtr m_entry;
 };
 
 #endif
